@@ -16,22 +16,23 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#ifndef ACK_H
-#define ACK_H
+#ifndef MPD_ACK_H
+#define MPD_ACK_H
 
-/* Common Errors */
-#define ACK_ERROR_NOT_LIST		1
-#define ACK_ERROR_ARG			2
-#define ACK_ERROR_PASSWORD		3
-#define ACK_ERROR_PERMISSION		4
-#define ACK_ERROR_UNKNOWN		5
+enum ack {
+	ACK_ERROR_NOT_LIST = 1,
+	ACK_ERROR_ARG = 2,
+	ACK_ERROR_PASSWORD = 3,
+	ACK_ERROR_PERMISSION = 4,
+	ACK_ERROR_UNKNOWN = 5,
 
-#define ACK_ERROR_NO_EXIST		50
-#define ACK_ERROR_PLAYLIST_MAX		51
-#define ACK_ERROR_SYSTEM		52
-#define ACK_ERROR_PLAYLIST_LOAD		53
-#define ACK_ERROR_UPDATE_ALREADY	54
-#define ACK_ERROR_PLAYER_SYNC		55
-#define ACK_ERROR_EXIST			56
+	ACK_ERROR_NO_EXIST = 50,
+	ACK_ERROR_PLAYLIST_MAX = 51,
+	ACK_ERROR_SYSTEM = 52,
+	ACK_ERROR_PLAYLIST_LOAD = 53,
+	ACK_ERROR_UPDATE_ALREADY = 54,
+	ACK_ERROR_PLAYER_SYNC = 55,
+	ACK_ERROR_EXIST = 56,
+};
 
 #endif
