@@ -20,11 +20,7 @@
  *
  */
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <sys/types.h>
-
+#include "os_compat.h"
 #include "compress.h"
 #include "utils.h"
 
@@ -48,7 +44,7 @@ static struct {
 	int target;
 	int gainmax;
 	int gainsmooth;
-	int buckets;
+	unsigned buckets;
 } prefs;
 
 #ifdef USE_X
@@ -56,9 +52,9 @@ static int mon_init;
 #endif
 
 void CompressCfg(int show_mon, int anticlip, int target, int gainmax,
-		 int gainsmooth, int buckets)
+		 int gainsmooth, unsigned buckets)
 {
-	static int lastsize;
+	static unsigned lastsize;
 
 	prefs.show_mon = show_mon;
 	prefs.anticlip = anticlip;
@@ -174,8 +170,8 @@ void CompressFree(void)
 void CompressDo(void *data, unsigned int length)
 {
 	int16_t *audio = (int16_t *)data, *ap;
-	int peak, pos;
-	int i;
+	int peak;
+	unsigned int i, pos;
 	int gr, gf, gn;
 	static int pn = -1;
 #ifdef STATS
@@ -358,7 +354,7 @@ void CompressDo(void *data, unsigned int length)
 	if (!pos)
 		pos = 1;
 
-	gr = ((gainTarget - gainCurrent) << 16)/pos;
+	gr = ((gainTarget - gainCurrent) << 16)/(int)pos;
 
 	/* Do the shiznit */
 	gf = gainCurrent << 16;
