@@ -16,13 +16,15 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#ifndef CONF_H
-#define CONF_H
+#ifndef MPD_CONF_H
+#define MPD_CONF_H
 
-#include "../config.h"
+#include <stdbool.h>
 
 #define CONF_MUSIC_DIR                  "music_directory"
 #define CONF_PLAYLIST_DIR               "playlist_directory"
+#define CONF_FOLLOW_INSIDE_SYMLINKS     "follow_inside_symlinks"
+#define CONF_FOLLOW_OUTSIDE_SYMLINKS    "follow_outside_symlinks"
 #define CONF_DB_FILE                    "db_file"
 #define CONF_LOG_FILE                   "log_file"
 #define CONF_ERROR_FILE                 "error_file"
@@ -47,8 +49,6 @@
 #define CONF_SAMPLERATE_CONVERTER       "samplerate_converter"
 #define CONF_AUDIO_BUFFER_SIZE          "audio_buffer_size"
 #define CONF_BUFFER_BEFORE_PLAY         "buffer_before_play"
-#define CONF_HTTP_BUFFER_SIZE           "http_buffer_size"
-#define CONF_HTTP_PREBUFFER_SIZE        "http_prebuffer_size"
 #define CONF_HTTP_PROXY_HOST            "http_proxy_host"
 #define CONF_HTTP_PROXY_PORT            "http_proxy_port"
 #define CONF_HTTP_PROXY_USER            "http_proxy_user"
@@ -64,6 +64,9 @@
 #define CONF_SAVE_ABSOLUTE_PATHS        "save_absolute_paths_in_playlists"
 #define CONF_GAPLESS_MP3_PLAYBACK	"gapless_mp3_playback"
 
+#define CONF_BOOL_UNSET         -1
+#define CONF_BOOL_INVALID       -2
+
 typedef struct _BlockParam {
 	char *name;
 	char *value;
@@ -80,20 +83,24 @@ typedef struct _ConfigParam {
 void initConf(void);
 void finishConf(void);
 
-void readConf(char *file);
+void readConf(const char *file);
 
 /* don't free the returned value
    set _last_ to NULL to get first entry */
-ConfigParam *getNextConfigParam(char *name, ConfigParam * last);
+ConfigParam *getNextConfigParam(const char *name, ConfigParam * last);
 
 #define getConfigParam(name) 	getNextConfigParam(name, NULL)
 
-char *getConfigParamValue(char *name);
+char *getConfigParamValue(const char *name);
 
-int getBoolConfigParam(char *name);
+BlockParam *getBlockParam(ConfigParam * param, const char *name);
 
-BlockParam *getBlockParam(ConfigParam * param, char *name);
+ConfigParam *parseConfigFilePath(const char *name, int force);
 
-ConfigParam *parseConfigFilePath(char *name, int force);
+int getBoolConfigParam(const char *name, int force);
+
+bool config_get_bool(const char *name, bool default_value);
+
+int getBoolBlockParam(ConfigParam *param, const char *name, int force);
 
 #endif
