@@ -16,34 +16,35 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#ifndef DB_UTILS_H
-#define DB_UTILS_H
-
-#include <stdio.h>
+#ifndef MPD_DB_UTILS_H
+#define MPD_DB_UTILS_H
 
 #include "locate.h"
 
-int printAllIn(int fd, char *name);
+struct client;
 
-int addAllIn(int fd, char *name);
+int printAllIn(struct client *client, const char *name);
 
-int addAllInToStoredPlaylist(int fd, char *name, char *utf8file);
+int addAllIn(const char *name);
 
-int printInfoForAllIn(int fd, char *name);
+int addAllInToStoredPlaylist(const char *name, const char *utf8file);
 
-int searchForSongsIn(int fd, char *name, int numItems,
-                     LocateTagItem * items);
+int printInfoForAllIn(struct client *client, const char *name);
 
-int findSongsIn(int fd, char *name, int numItems, LocateTagItem * items);
+int searchForSongsIn(struct client *client, const char *name,
+		     int numItems, LocateTagItem * items);
 
-int searchStatsForSongsIn(int fd, char *name, int numItems,
-                          LocateTagItem * items);
+int findSongsIn(struct client *client, const char *name,
+		int numItems, LocateTagItem * items);
 
-int countSongsIn(int fd, char *name);
+int searchStatsForSongsIn(struct client *client, const char *name,
+			  int numItems, LocateTagItem * items);
 
-unsigned long sumSongTimesIn(int fd, char *name);
+int countSongsIn(const char *name);
 
-int listAllUniqueTags(int fd, int type, int numConditiionals,
+unsigned long sumSongTimesIn(const char *name);
+
+int listAllUniqueTags(struct client *client, int type, int numConditiionals,
 		      LocateTagItem * conditionals);
 
 void printSavedMemoryFromFilenames(void);
