@@ -17,22 +17,13 @@
  */
 
 #include "listen.h"
-#include "interface.h"
+#include "client.h"
 #include "conf.h"
 #include "log.h"
 #include "utils.h"
+#include "os_compat.h"
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <sys/socket.h>
-#include <sys/stat.h>
-#include <sys/param.h>
-#include <netinet/in.h>
-#include <netdb.h>
-#include <string.h>
-#include <errno.h>
-#include <resolv.h>
-#include <fcntl.h>
+#include "../config.h"
 
 #define MAXHOSTNAME 	1024
 
@@ -48,7 +39,7 @@
 
 static int *listenSockets;
 static int numberOfListenSockets;
-static int boundPort;
+int boundPort;
 
 /*
  * redirect stdin to /dev/null to work around a libao bug
@@ -78,33 +69,19 @@ static void redirect_stdin(void)
 		FATAL("dup2 stdin: %s\n", strerror(errno));
 }
 
-static int establishListen(unsigned int port,
-                           struct sockaddr *addrp, socklen_t addrlen)
+static int establishListen(int pf, const struct sockaddr *addrp,
+			   socklen_t addrlen)
 {
-	int pf = 0;
 	int sock;
 	int allowReuse = ALLOW_REUSE;
-
-	switch (addrp->sa_family) {
-	case AF_INET:
-		pf = PF_INET;
-		break;
-#ifdef HAVE_IPV6
-	case AF_INET6:
-		pf = PF_INET6;
-		break;
+#ifdef HAVE_STRUCT_UCRED
+	int passcred = 1;
 #endif
-	case AF_UNIX:
-		pf = PF_UNIX;
-		break;
-	default:
-		FATAL("unknown address family: %i\n", addrp->sa_family);
-	}
 
 	if ((sock = socket(pf, SOCK_STREAM, 0)) < 0)
 		FATAL("socket < 0\n");
 
-	if (fcntl(sock, F_SETFL, fcntl(sock, F_GETFL) | O_NONBLOCK) < 0) {
+	if (set_nonblocking(sock) < 0) {
 		FATAL("problems setting nonblocking on listen socket: %s\n",
 		      strerror(errno));
 	}
@@ -122,6 +99,10 @@ static int establishListen(unsigned int port,
 	if (listen(sock, 5) < 0)
 		FATAL("problems listen'ing: %s\n", strerror(errno));
 
+#ifdef HAVE_STRUCT_UCRED
+	setsockopt(sock, SOL_SOCKET, SO_PASSCRED, &passcred, sizeof(passcred));
+#endif
+
 	numberOfListenSockets++;
 	listenSockets =
 	    xrealloc(listenSockets, sizeof(int) * numberOfListenSockets);
@@ -131,11 +112,13 @@ static int establishListen(unsigned int port,
 	return 0;
 }
 
-static void parseListenConfigParam(unsigned int port, ConfigParam * param)
+static void
+parseListenConfigParam(G_GNUC_UNUSED unsigned int port, ConfigParam * param)
 {
-	struct sockaddr *addrp = NULL;
-	socklen_t addrlen = 0;
-	struct sockaddr_in sin;
+	const struct sockaddr *addrp;
+	socklen_t addrlen;
+#ifdef HAVE_TCP
+	struct sockaddr_in sin4;
 #ifdef HAVE_IPV6
 	struct sockaddr_in6 sin6;
 	int useIpv6 = ipv6Supported();
@@ -144,65 +127,94 @@ static void parseListenConfigParam(unsigned int port, ConfigParam * param)
 	sin6.sin6_port = htons(port);
 	sin6.sin6_family = AF_INET6;
 #endif
-	memset(&sin, 0, sizeof(struct sockaddr_in));
-	sin.sin_port = htons(port);
-	sin.sin_family = AF_INET;
+	memset(&sin4, 0, sizeof(struct sockaddr_in));
+	sin4.sin_port = htons(port);
+	sin4.sin_family = AF_INET;
+#endif /* HAVE_TCP */
 
 	if (!param || 0 == strcmp(param->value, "any")) {
+#ifdef HAVE_TCP
 		DEBUG("binding to any address\n");
 #ifdef HAVE_IPV6
 		if (useIpv6) {
 			sin6.sin6_addr = in6addr_any;
-			addrp = (struct sockaddr *)&sin6;
+			addrp = (const struct sockaddr *)&sin6;
 			addrlen = sizeof(struct sockaddr_in6);
-			if (establishListen(port, addrp, addrlen) < 0)
+			if (establishListen(PF_INET6, addrp, addrlen) < 0)
 				BINDERROR();
 		}
 #endif
-		sin.sin_addr.s_addr = INADDR_ANY;
-		addrp = (struct sockaddr *)&sin;
+		sin4.sin_addr.s_addr = INADDR_ANY;
+		addrp = (const struct sockaddr *)&sin4;
 		addrlen = sizeof(struct sockaddr_in);
 #ifdef HAVE_IPV6
-		if ((establishListen(port, addrp, addrlen) < 0) && !useIpv6) {
+		if ((establishListen(PF_INET, addrp, addrlen) < 0) && !useIpv6) {
 #else
-		if (establishListen(port, addrp, addrlen) < 0) {
+		if (establishListen(PF_INET, addrp, addrlen) < 0) {
 #endif
 			BINDERROR();
 		}
-	} else {
-		struct hostent *he;
-		DEBUG("binding to address for %s\n", param->value);
-		if (!(he = gethostbyname(param->value))) {
-			FATAL("can't lookup host \"%s\" at line %i\n",
-			      param->value, param->line);
-		}
-		switch (he->h_addrtype) {
-#ifdef HAVE_IPV6
-		case AF_INET6:
-			if (!useIpv6) {
-				FATAL("no IPv6 support, but a IPv6 address "
-				      "found for \"%s\" at line %i\n",
-				      param->value, param->line);
-			}
-			memcpy((char *)&sin6.sin6_addr.s6_addr,
-			       (char *)he->h_addr, he->h_length);
-			addrp = (struct sockaddr *)&sin6;
-			addrlen = sizeof(struct sockaddr_in6);
-			break;
-#endif
-		case AF_INET:
-			memcpy((char *)&sin.sin_addr.s_addr,
-			       (char *)he->h_addr, he->h_length);
-			addrp = (struct sockaddr *)&sin;
-			addrlen = sizeof(struct sockaddr_in);
-			break;
-		default:
-			FATAL("address type for \"%s\" is not IPv4 or IPv6 "
-			      "at line %i\n", param->value, param->line);
-		}
+#else /* HAVE_TCP */
+		FATAL("TCP support is disabled\n");
+#endif /* HAVE_TCP */
+#ifdef HAVE_UN
+	} else if (param->value[0] == '/') {
+		size_t path_length;
+		struct sockaddr_un s_un;
 
-		if (establishListen(port, addrp, addrlen) < 0)
-			BINDERROR();
+		path_length = strlen(param->value);
+		if (path_length >= sizeof(s_un.sun_path))
+			FATAL("unix socket path is too long\n");
+
+		unlink(param->value);
+
+		s_un.sun_family = AF_UNIX;
+		memcpy(s_un.sun_path, param->value, path_length + 1);
+
+		addrp = (const struct sockaddr *)&s_un;
+		addrlen = sizeof(s_un);
+
+		if (establishListen(PF_UNIX, addrp, addrlen) < 0)
+			FATAL("unable to bind to %s: %s\n",
+			      param->value, strerror(errno));
+
+		/* allow everybody to connect */
+		chmod(param->value, 0666);
+
+#endif /* HAVE_UN */
+	} else {
+#ifdef HAVE_TCP
+		struct addrinfo hints, *ai, *i;
+		char service[20];
+		int ret;
+
+		DEBUG("binding to address for %s\n", param->value);
+
+		memset(&hints, 0, sizeof(hints));
+		hints.ai_flags = AI_PASSIVE;
+#ifdef AI_ADDRCONFIG
+		hints.ai_flags |= AI_ADDRCONFIG;
+#endif
+		hints.ai_family = PF_UNSPEC;
+		hints.ai_socktype = SOCK_STREAM;
+		hints.ai_protocol = IPPROTO_TCP;
+
+		snprintf(service, sizeof(service), "%u", port);
+
+		ret = getaddrinfo(param->value, service, &hints, &ai);
+		if (ret != 0)
+			FATAL("can't lookup host \"%s\" at line %i: %s\n",
+			      param->value, param->line, gai_strerror(ret));
+
+		for (i = ai; i != NULL; i = i->ai_next)
+			if (establishListen(i->ai_family, i->ai_addr,
+					    i->ai_addrlen) < 0)
+				BINDERROR();
+
+		freeaddrinfo(ai);
+#else /* HAVE_TCP */
+		FATAL("TCP support is disabled\n");
+#endif /* HAVE_TCP */
 	}
 }
 
@@ -261,6 +273,22 @@ void freeAllListenSockets(void)
 	listenSockets = NULL;
 }
 
+static int get_remote_uid(int fd)
+{
+#ifdef HAVE_STRUCT_UCRED
+	struct ucred cred;
+	socklen_t len = sizeof (cred);
+
+	if (getsockopt(fd, SOL_SOCKET, SO_PEERCRED, &cred, &len) < 0)
+		return 0;
+
+	return cred.uid;
+#else
+	(void)fd;
+	return -1;
+#endif
+}
+
 void getConnections(fd_set * fds)
 {
 	int i;
@@ -272,7 +300,7 @@ void getConnections(fd_set * fds)
 		if (FD_ISSET(listenSockets[i], fds)) {
 			if ((fd = accept(listenSockets[i], &sockAddr, &socklen))
 			    >= 0) {
-				openAInterface(fd, &sockAddr);
+				client_new(fd, &sockAddr, get_remote_uid(fd));
 			} else if (fd < 0
 				   && (errno != EAGAIN && errno != EINTR)) {
 				ERROR("Problems accept()'ing\n");
@@ -280,8 +308,3 @@ void getConnections(fd_set * fds)
 		}
 	}
 }
-
-int getBoundPort(void)
-{
-	return boundPort;
-}
