@@ -16,16 +16,13 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#ifndef LISTEN_H
-#define LISTEN_H
+#ifndef MPD_LISTEN_H
+#define MPD_LISTEN_H
 
-#include "../config.h"
-
-#include <sys/time.h>
-#include <sys/types.h>
-#include <unistd.h>
 #include <sys/select.h>
 
+extern int boundPort;
+
 void listenOnPort(void);
 
 void getConnections(fd_set * fds);
@@ -36,6 +33,4 @@ void freeAllListenSockets(void);
 /* fdmax should be initialized to something */
 void addListenSocketsToFdSet(fd_set * fds, int *fdmax);
 
-int getBoundPort(void);
-
 #endif
