@@ -17,21 +17,32 @@
  */
 
 #include "log.h"
-
 #include "conf.h"
-#include "myfprintf.h"
-#include "utils.h"
 
 #include <assert.h>
-#include <stdlib.h>
+#include <sys/types.h>
+#include <sys/stat.h>
 #include <string.h>
 #include <stdarg.h>
+#include <fcntl.h>
+#include <stdio.h>
+#include <stdlib.h>
 #include <time.h>
+#include <unistd.h>
+#include <errno.h>
+#include <pthread.h>
+#include <glib.h>
 
-static unsigned int logLevel = LOG_LEVEL_LOW;
-static int warningFlushed;
-static int stdout_mode = 1;
-static char *warningBuffer;
+#define LOG_LEVEL_SECURE G_LOG_LEVEL_INFO
+
+#define LOG_DATE_BUF_SIZE 16
+#define LOG_DATE_LEN (LOG_DATE_BUF_SIZE - 1)
+
+static unsigned int log_threshold = G_LOG_LEVEL_MESSAGE;
+
+static const char *log_charset;
+
+static bool stdout_mode = true;
 static int out_fd = -1;
 static int err_fd = -1;
 static const char *out_filename;
@@ -39,8 +50,8 @@ static const char *err_filename;
 
 static void redirect_logs(void)
 {
-	assert(out_fd > 0);
-	assert(err_fd > 0);
+	assert(out_fd >= 0);
+	assert(err_fd >= 0);
 	if (dup2(out_fd, STDOUT_FILENO) < 0)
 		FATAL("problems dup2 stdout : %s\n", strerror(errno));
 	if (dup2(err_fd, STDERR_FILENO) < 0)
@@ -49,97 +60,95 @@ static void redirect_logs(void)
 
 static const char *log_date(void)
 {
-	static char buf[16];
+	static char buf[LOG_DATE_BUF_SIZE];
 	time_t t = time(NULL);
-	strftime(buf, 16, "%b %d %H:%M : ", localtime(&t));
+	strftime(buf, LOG_DATE_BUF_SIZE, "%b %d %H:%M : ", localtime(&t));
 	return buf;
 }
 
-#define BUFFER_LENGTH	4096
-static void buffer_warning(const char *fmt, va_list args)
+/**
+ * Determines the length of the string excluding trailing whitespace
+ * characters.
+ */
+static int
+chomp_length(const char *p)
 {
-	char buffer[BUFFER_LENGTH];
-	char *tmp = buffer;
-	size_t len = BUFFER_LENGTH;
+	size_t length = strlen(p);
 
-	if (!stdout_mode) {
-		memcpy(buffer, log_date(), 15);
-		tmp += 15;
-		len -= 15;
-	}
+	while (length > 0 && g_ascii_isspace(p[length - 1]))
+		--length;
 
-	vsnprintf(tmp, len, fmt, args);
-	warningBuffer = appendToString(warningBuffer, buffer);
-
-	va_end(args);
+	return (int)length;
 }
 
-static void do_log(FILE *fp, const char *fmt, va_list args)
+static void
+mpd_log_func(const gchar *log_domain,
+	     G_GNUC_UNUSED GLogLevelFlags log_level,
+	     const gchar *message, G_GNUC_UNUSED gpointer user_data)
 {
-	if (!stdout_mode)
-		fwrite(log_date(), 15, 1, fp);
-	vfprintf(fp, fmt, args);
+	FILE *file = log_level <= G_LOG_LEVEL_WARNING
+		? stderr : stdout;
+	char *converted;
+
+	if (log_level > (int)log_threshold)
+		return;
+
+	if (log_charset != NULL) {
+		converted = g_convert_with_fallback(message, -1,
+						    log_charset, "utf-8",
+						    NULL, NULL, NULL, NULL);
+		if (converted != NULL)
+			message = converted;
+	} else
+		converted = NULL;
+
+	if (log_domain == NULL)
+		log_domain = "";
+
+	fprintf(file, "%s%s%s%.*s\n",
+		stdout_mode ? "" : log_date(),
+		log_domain, *log_domain == 0 ? "" : ": ",
+		chomp_length(message), message);
+
+	g_free(converted);
 }
 
-void flushWarningLog(void)
-{
-	char *s = warningBuffer;
-
-	DEBUG("flushing warning messages\n");
-
-	if (warningBuffer != NULL)
-	{
-		while (s != NULL) {
-			char *next = strchr(s, '\n');
-			if (next == NULL) break;
-			*next = '\0';
-			next++;
-			fprintf(stderr, "%s\n", s);
-			s = next;
-		}
-
-		warningBuffer = NULL;
-	}
-
-	warningFlushed = 1;
-
-	DEBUG("done flushing warning messages\n");
-}
-
-void initLog(const int verbose)
+void initLog(bool verbose)
 {
 	ConfigParam *param;
 
+	g_get_charset(&log_charset);
+
+	g_log_set_default_handler(mpd_log_func, NULL);
+
 	/* unbuffer stdout, stderr is unbuffered by default, leave it */
 	setvbuf(stdout, (char *)NULL, _IONBF, 0);
 
 	if (verbose) {
-		logLevel = LOG_LEVEL_DEBUG;
+		log_threshold = G_LOG_LEVEL_DEBUG;
 		return;
 	}
 	if (!(param = getConfigParam(CONF_LOG_LEVEL)))
 		return;
 	if (0 == strcmp(param->value, "default")) {
-		logLevel = LOG_LEVEL_LOW;
+		log_threshold = G_LOG_LEVEL_MESSAGE;
 	} else if (0 == strcmp(param->value, "secure")) {
-		logLevel = LOG_LEVEL_SECURE;
+		log_threshold = LOG_LEVEL_SECURE;
 	} else if (0 == strcmp(param->value, "verbose")) {
-		logLevel = LOG_LEVEL_DEBUG;
+		log_threshold = G_LOG_LEVEL_DEBUG;
 	} else {
 		FATAL("unknown log level \"%s\" at line %i\n",
 		      param->value, param->line);
 	}
 }
 
-void open_log_files(const int use_stdout)
+void open_log_files(bool use_stdout)
 {
 	mode_t prev;
 	ConfigParam *param;
 
-	if (use_stdout) {
-		flushWarningLog();
+	if (use_stdout)
 		return;
-	}
 
 	prev = umask(0066);
 	param = parseConfigFilePath(CONF_LOG_FILE, 1);
@@ -159,49 +168,40 @@ void open_log_files(const int use_stdout)
 	umask(prev);
 }
 
-void setup_log_output(const int use_stdout)
+void setup_log_output(bool use_stdout)
 {
 	fflush(NULL);
 	if (!use_stdout) {
 		redirect_logs();
-		stdout_mode = 0;
+		stdout_mode = false;
+		log_charset = NULL;
 	}
 }
 
-#define log_func(func,level,fp) \
-mpd_printf void func(const char *fmt, ...) \
+#define log_func(func,level) \
+G_GNUC_PRINTF(1, 2) void func(const char *fmt, ...) \
 { \
-	if (logLevel >= level) { \
+	if (level <= (int)log_threshold) { \
 		va_list args; \
 		va_start(args, fmt); \
-		do_log(fp, fmt, args); \
+		g_logv(NULL, level, fmt, args);	\
 		va_end(args); \
 	} \
 }
 
-log_func(ERROR, 0, stderr)
-log_func(LOG, 0, stdout)
-log_func(SECURE, LOG_LEVEL_SECURE, stdout)
-log_func(DEBUG, LOG_LEVEL_DEBUG, stdout)
+log_func(ERROR, G_LOG_LEVEL_WARNING)
+log_func(WARNING, G_LOG_LEVEL_WARNING)
+log_func(LOG, G_LOG_LEVEL_MESSAGE)
+log_func(SECURE, LOG_LEVEL_SECURE)
+log_func(DEBUG, G_LOG_LEVEL_DEBUG)
 
 #undef log_func
 
-void WARNING(const char *fmt, ...)
+G_GNUC_PRINTF(1, 2) G_GNUC_NORETURN void FATAL(const char *fmt, ...)
 {
 	va_list args;
 	va_start(args, fmt);
-	if (warningFlushed) {
-		do_log(stderr, fmt, args);
-	} else
-		buffer_warning(fmt, args);
-	va_end(args);
-}
-
-mpd_printf mpd_noreturn void FATAL(const char *fmt, ...)
-{
-	va_list args;
-	va_start(args, fmt);
-	do_log(stderr, fmt, args);
+	g_logv(NULL, G_LOG_LEVEL_ERROR, fmt, args);
 	va_end(args);
 	exit(EXIT_FAILURE);
 }
@@ -243,9 +243,9 @@ void close_log_files(void)
 {
 	if (stdout_mode)
 		return;
-	assert(out_fd > 0);
-	assert(err_fd > 0);
-	xclose(out_fd);
-	xclose(err_fd);
+	assert(out_fd >= 0);
+	assert(err_fd >= 0);
+	close(out_fd);
+	close(err_fd);
 }
 
