@@ -16,35 +16,27 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#ifndef LOG_H
-#define LOG_H
+#ifndef MPD_LOG_H
+#define MPD_LOG_H
 
-#include "../config.h"
-#include "gcc.h"
+#include <glib.h>
+#include <stdbool.h>
 
-#include <unistd.h>
+G_GNUC_PRINTF(1, 2) void ERROR(const char *fmt, ...);
+G_GNUC_PRINTF(1, 2) void LOG(const char *fmt, ...);
+G_GNUC_PRINTF(1, 2) void SECURE(const char *fmt, ...);
+G_GNUC_PRINTF(1, 2) void DEBUG(const char *fmt, ...);
+G_GNUC_PRINTF(1, 2) void WARNING(const char *fmt, ...);
+G_GNUC_PRINTF(1, 2) G_GNUC_NORETURN void FATAL(const char *fmt, ...);
 
-#define LOG_LEVEL_LOW		0
-#define LOG_LEVEL_SECURE	1
-#define LOG_LEVEL_DEBUG		2
+void initLog(bool verbose);
 
-mpd_printf void ERROR(const char *fmt, ...);
-mpd_printf void LOG(const char *fmt, ...);
-mpd_printf void SECURE(const char *fmt, ...);
-mpd_printf void DEBUG(const char *fmt, ...);
-mpd_printf void WARNING(const char *fmt, ...);
-mpd_printf void FATAL(const char *fmt, ...);
+void setup_log_output(bool use_stdout);
 
-void initLog(const int verbose);
-
-void setup_log_output(const int use_stdout);
-
-void open_log_files(const int use_stdout);
+void open_log_files(bool use_stdout);
 
 int cycle_log_files(void);
 
 void close_log_files(void);
 
-void flushWarningLog(void);
-
 #endif /* LOG_H */
