@@ -16,37 +16,29 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#ifndef LS_H
-#define LS_H
+#ifndef MPD_LS_H
+#define MPD_LS_H
 
-#include "../config.h"
+#include "decoder_list.h"
 
-#include "inputPlugin.h"
+#include <stdbool.h>
 
-#include <stdio.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <unistd.h>
-#include <time.h>
+struct stat;
+struct client;
 
-int lsPlaylists(int fd, char *utf8path);
+const char *getSuffix(const char *utf8file);
 
-char *getSuffix(char *utf8file);
+/**
+ * Checks whether the specified URI has a schema in the form
+ * "scheme://".
+ */
+bool uri_has_scheme(const char *uri);
 
-int isValidRemoteUtf8Url(char *utf8url);
+bool isRemoteUrl(const char *url);
 
-int isRemoteUrl(char *url);
+const struct decoder_plugin *
+hasMusicSuffix(const char *utf8file, unsigned int next);
 
-int myStat(char *utf8file, struct stat *st);
-
-int isDir(char *utf8name);
-
-int isPlaylist(char *utf8file);
-
-InputPlugin *hasMusicSuffix(char *utf8file, unsigned int next);
-
-InputPlugin *isMusic(char *utf8file, time_t * mtime, unsigned int next);
-
-int printRemoteUrlHandlers(int fd);
+void printRemoteUrlHandlers(struct client *client);
 
 #endif
