@@ -16,47 +16,46 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include "interface.h"
+#include "client.h"
+#include "idle.h"
 #include "command.h"
 #include "playlist.h"
-#include "directory.h"
-#include "player.h"
+#include "database.h"
+#include "update.h"
+#include "player_thread.h"
 #include "listen.h"
 #include "conf.h"
 #include "path.h"
+#include "mapper.h"
 #include "playerData.h"
+#include "pipe.h"
+#include "decoder_thread.h"
+#include "decoder_control.h"
+#include "player_control.h"
 #include "stats.h"
 #include "sig_handlers.h"
 #include "audio.h"
 #include "volume.h"
 #include "log.h"
 #include "permission.h"
-#include "replayGain.h"
-#include "inputPlugin.h"
+#include "replay_gain.h"
+#include "decoder_list.h"
 #include "audioOutput.h"
-#include "inputStream.h"
+#include "input_stream.h"
 #include "state_file.h"
 #include "tag.h"
-#include "tagTracker.h"
 #include "dbUtils.h"
 #include "../config.h"
-#include "utils.h"
 #include "normalize.h"
 #include "zeroconf.h"
+#include "main_notify.h"
+#include "os_compat.h"
 
-#include <stdio.h>
-#include <sys/select.h>
-#include <sys/types.h>
-#include <sys/wait.h>
-#include <sys/stat.h>
-#include <stdlib.h>
-#include <string.h>
-#include <errno.h>
-#include <fcntl.h>
-#include <pwd.h>
-#include <grp.h>
-#include <time.h>
-#include <unistd.h>
+#include <glib.h>
+
+#ifdef HAVE_LOCALE
+#include <locale.h>
+#endif
 
 #define SYSTEM_CONFIG_FILE_LOCATION	"/etc/mpd.conf"
 #define USER_CONFIG_FILE_LOCATION	"/.mpdconf"
@@ -69,83 +68,41 @@ typedef struct _Options {
 	int verbose;
 } Options;
 
-/* 
- * from git-1.3.0, needed for solaris
- */
-#ifndef HAVE_SETENV
-static int setenv(const char *name, const char *value, int replace)
-{
-	int out;
-	size_t namelen, valuelen;
-	char *envstr;
-
-	if (!name || !value)
-		return -1;
-	if (!replace) {
-		char *oldval = NULL;
-		oldval = getenv(name);
-		if (oldval)
-			return 0;
-	}
-
-	namelen = strlen(name);
-	valuelen = strlen(value);
-	envstr = xmalloc((namelen + valuelen + 2));
-	if (!envstr)
-		return -1;
-
-	memcpy(envstr, name, namelen);
-	envstr[namelen] = '=';
-	memcpy(envstr + namelen + 1, value, valuelen);
-	envstr[namelen + valuelen + 1] = 0;
-
-	out = putenv(envstr);
-	/* putenv(3) makes the argument string part of the environment,
-	 * and changing that string modifies the environment --- which
-	 * means we do not own that storage anymore.  Do not free
-	 * envstr.
-	 */
-
-	return out;
-}
-#endif /* HAVE_SETENV */
-
 static void usage(char *argv[])
 {
-	ERROR("usage:\n");
-	ERROR("   %s [options] <conf file>\n", argv[0]);
-	ERROR("   %s [options]   (searches for ~%s then %s)\n",
-	      argv[0], USER_CONFIG_FILE_LOCATION, SYSTEM_CONFIG_FILE_LOCATION);
-	ERROR("\n");
-	ERROR("options:\n");
-	ERROR("   --help             this usage statement\n");
-	ERROR("   --kill             kill the currently running mpd session\n");
-	ERROR
-	    ("   --create-db        force (re)creation of database and exit\n");
-	ERROR
-	    ("   --no-create-db     don't create database, even if it doesn't exist\n");
-	ERROR("   --no-daemon        don't detach from console\n");
-	ERROR("   --stdout           print messages to stdout and stderr\n");
-	ERROR("   --verbose          verbose logging\n");
-	ERROR("   --version          prints version information\n");
+	printf("usage:\n"
+	       "   %s [options] <conf file>\n"
+	       "   %s [options]   (searches for ~" USER_CONFIG_FILE_LOCATION
+	       " then " SYSTEM_CONFIG_FILE_LOCATION ")\n",
+	       argv[0], argv[0]);
+	puts("\n"
+	     "options:\n"
+	     "   --help             this usage statement\n"
+	     "   --kill             kill the currently running mpd session\n"
+	     "   --create-db        force (re)creation of database and exit\n"
+	     "   --no-create-db     don't create database, even if it doesn't exist\n"
+	     "   --no-daemon        don't detach from console\n"
+	     "   --stdout           print messages to stdout and stderr\n"
+	     "   --verbose          verbose logging\n"
+	     "   --version          prints version information\n");
 }
 
 static void version(void)
 {
-	LOG("mpd (MPD: Music Player Daemon) %s\n", VERSION);
-	LOG("\n");
-	LOG("Copyright (C) 2003-2007 Warren Dukes <warren.dukes@gmail.com>\n");
-	LOG("This is free software; see the source for copying conditions.  There is NO\n");
-	LOG("warranty; not even MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n");
-	LOG("\n");
-	LOG("Supported formats:\n");
+	puts(PACKAGE " (MPD: Music Player Daemon) " VERSION " \n"
+	     "\n"
+	     "Copyright (C) 2003-2007 Warren Dukes <warren.dukes@gmail.com>\n"
+	     "Copyright (C) 2008 Max Kellermann <max@duempel.org>\n"
+	     "This is free software; see the source for copying conditions.  There is NO\n"
+	     "warranty; not even MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"
+	     "\n"
+	     "Supported formats:\n");
 
-	initInputPlugins();
-	printAllInputPluginSuffixes(stdout);
+	decoder_plugin_init_all();
+	decoder_plugin_print_all_suffixes(stdout);
 
-	LOG("\n");
-	LOG("Supported outputs:\n");
-	loadAudioDrivers();
+	puts("\n"
+	     "Supported outputs:\n");
 	printAllOutputPluginTypes(stdout);
 }
 
@@ -162,7 +119,7 @@ static void parseOptions(int argc, char **argv, Options * options)
 	if (argc > 1) {
 		int i = 1;
 		while (i < argc) {
-			if (strncmp(argv[i], "--", 2) == 0) {
+			if (g_str_has_prefix(argv[i], "--")) {
 				if (strcmp(argv[i], "--help") == 0) {
 					usage(argv);
 					exit(EXIT_SUCCESS);
@@ -208,10 +165,10 @@ static void parseOptions(int argc, char **argv, Options * options)
 		} else if (argcLeft == 1) {
 			struct stat st;
 			char *homedir = getenv("HOME");
-			char userfile[MAXPATHLEN + 1] = "";
+			char userfile[MPD_PATH_MAX] = "";
 			if (homedir && (strlen(homedir) +
 					strlen(USER_CONFIG_FILE_LOCATION)) <
-			    MAXPATHLEN) {
+			    MPD_PATH_MAX) {
 				strcpy(userfile, homedir);
 				strcat(userfile, USER_CONFIG_FILE_LOCATION);
 			}
@@ -229,15 +186,6 @@ static void parseOptions(int argc, char **argv, Options * options)
 	exit(EXIT_FAILURE);
 }
 
-static void closeAllFDs(void)
-{
-	int i;
-	int fds = getdtablesize();
-
-	for (i = 3; i < fds; i++)
-		close(i);
-}
-
 static void changeToUser(void)
 {
 	ConfigParam *param = getConfigParam(CONF_USER);
@@ -274,24 +222,23 @@ static void changeToUser(void)
 
 		/* this is needed by libs such as arts */
 		if (userpwd->pw_dir) {
-			setenv("HOME", userpwd->pw_dir, 1);
+			g_setenv("HOME", userpwd->pw_dir, true);
 		}
 	}
 }
 
 static void openDB(Options * options, char *argv0)
 {
-	if (options->createDB > 0 || readDirectoryDB() < 0) {
+	if (options->createDB > 0 || db_load() < 0) {
 		if (options->createDB < 0) {
 			FATAL("can't open db file and using "
 			      "\"--no-create-db\" command line option\n"
 			      "try running \"%s --create-db\"\n", argv0);
 		}
-		flushWarningLog();
-		if (checkDirectoryDB() < 0)
+		if (db_check() < 0)
 			exit(EXIT_FAILURE);
-		initMp3Directory();
-		if (writeDirectoryDB() < 0)
+		db_init();
+		if (db_save() < 0)
 			exit(EXIT_FAILURE);
 		if (options->createDB)
 			exit(EXIT_SUCCESS);
@@ -364,7 +311,7 @@ static void cleanUpPidFile(void)
 	unlink(pidFileParam->value);
 }
 
-static void killFromPidFile(char *cmd, int killOption)
+static void killFromPidFile(void)
 {
 	FILE *fp;
 	ConfigParam *pidFileParam = parseConfigFilePath(CONF_PID_FILE, 0);
@@ -395,18 +342,25 @@ int main(int argc, char *argv[])
 {
 	Options options;
 	clock_t start;
+	GTimer *save_state_timer;
 
-	closeAllFDs();
+#ifdef HAVE_LOCALE
+	/* initialize locale */
+	setlocale(LC_CTYPE,"");
+#endif
+
+	/* enable GLib's thread safety code */
+	g_thread_init(NULL);
 
 	initConf();
 
 	parseOptions(argc, argv, &options);
 
 	if (options.kill)
-		killFromPidFile(argv[0], options.kill);
+		killFromPidFile();
 
 	initStats();
-	initTagConfig();
+	tag_lib_init();
 	initLog(options.verbose);
 
 	if (options.createDB <= 0)
@@ -416,22 +370,29 @@ int main(int argc, char *argv[])
 
 	open_log_files(options.stdOutput);
 
-	initPaths();
+	path_global_init();
+	mapper_init();
 	initPermissions();
 	initPlaylist();
-	initInputPlugins();
+	decoder_plugin_init_all();
+	update_global_init();
+
+	init_main_notify();
 
 	openDB(&options, argv[0]);
 
-	initCommands();
+	command_init();
 	initPlayerData();
+	pc_init(buffered_before_play);
+	music_pipe_init(buffered_chunks, &pc.notify);
+	dc_init();
 	initAudioConfig();
 	initAudioDriver();
 	initVolume();
-	initInterfaces();
-	initReplayGainState();
+	client_manager_init();
+	replay_gain_global_init();
 	initNormalization();
-	initInputStream();
+	input_stream_global_init();
 
 	daemonize(&options);
 
@@ -442,39 +403,65 @@ int main(int argc, char *argv[])
 	initZeroconf();
 
 	openVolumeDevice();
+	decoder_thread_start();
+	player_create();
 	read_state_file();
 
-	while (COMMAND_RETURN_KILL != doIOForInterfaces()) {
-		if (COMMAND_RETURN_KILL == handlePendingSignals())
-			break;
+	save_state_timer = g_timer_new();
+
+	while (COMMAND_RETURN_KILL != client_manager_io() &&
+	       COMMAND_RETURN_KILL != handlePendingSignals()) {
+		unsigned flags;
+
 		syncPlayerAndPlaylist();
-		closeOldInterfaces();
-		readDirectoryDBIfUpdateIsFinished();
+		client_manager_expire();
+		reap_update_task();
+
+		/* send "idle" notificaions to all subscribed
+		   clients */
+		flags = idle_get();
+		if (flags != 0)
+			client_manager_idle_add(flags);
+
+		if (g_timer_elapsed(save_state_timer, NULL) >= 5 * 60) {
+			g_debug("Saving state file\n");
+			write_state_file();
+			g_timer_start(save_state_timer);
+		}
 	}
 
+	g_timer_destroy(save_state_timer);
+
 	write_state_file();
 	playerKill();
 	finishZeroconf();
-	freeAllInterfaces();
+	client_manager_deinit();
 	closeAllListenSockets();
 	finishPlaylist();
 
 	start = clock();
-	closeMp3Directory();
-	DEBUG("closeMp3Directory took %f seconds\n", 
+	db_finish();
+	DEBUG("db_finish took %f seconds\n",
 	      ((float)(clock()-start))/CLOCKS_PER_SEC);
 
+	deinit_main_notify();
+
+	input_stream_global_finish();
 	finishNormalization();
 	finishAudioDriver();
 	finishAudioConfig();
 	finishVolume();
-	finishPaths();
+	mapper_finish();
+	path_global_finish();
 	finishPermissions();
-	finishCommands();
-	finishInputPlugins();
+	dc_deinit();
+	pc_deinit();
+	command_finish();
+	update_global_finish();
+	decoder_plugin_deinit_all();
+	music_pipe_free();
 	cleanUpPidFile();
 	finishConf();
-	freePlayerData();
 
 	close_log_files();
 	return EXIT_SUCCESS;
