@@ -16,19 +16,20 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#include "normalize.h"
 #include "compress.h"
 #include "conf.h"
-#include "normalize.h"
+#include "audio_format.h"
 
-#include <stdlib.h>
+#define DEFAULT_VOLUME_NORMALIZATION 0
 
 int normalizationEnabled;
 
 void initNormalization(void)
 {
-	normalizationEnabled = getBoolConfigParam(CONF_VOLUME_NORMALIZATION);
-	if (normalizationEnabled == -1) normalizationEnabled = 0;
-	else if (normalizationEnabled < 0) exit(EXIT_FAILURE);
+	normalizationEnabled = getBoolConfigParam(CONF_VOLUME_NORMALIZATION, 1);
+	if (normalizationEnabled == CONF_BOOL_UNSET)
+		normalizationEnabled = DEFAULT_VOLUME_NORMALIZATION;
 
 	if (normalizationEnabled)
 		CompressCfg(0, ANTICLIP, TARGET, GAINMAX, GAINSMOOTH, BUCKETS);
@@ -39,7 +40,8 @@ void finishNormalization(void)
 	if (normalizationEnabled) CompressFree();
 }
 
-void normalizeData(char *buffer, int bufferSize, AudioFormat *format)
+void normalizeData(char *buffer, int bufferSize,
+		   const struct audio_format *format)
 {
 	if ((format->bits != 16) || (format->channels != 2)) return;
 
