@@ -16,10 +16,10 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#ifndef NORMALIZE_H
-#define NORMALIZE_H
+#ifndef MPD_NORMALIZE_H
+#define MPD_NORMALIZE_H
 
-#include "audio.h"
+struct audio_format;
 
 extern int normalizationEnabled;
 
@@ -27,6 +27,7 @@ void initNormalization(void);
 
 void finishNormalization(void);
 
-void normalizeData(char *buffer, int bufferSize, AudioFormat *format);
+void normalizeData(char *buffer, int bufferSize,
+		   const struct audio_format *format);
 
 #endif /* !NORMALIZE_H */
