@@ -16,10 +16,8 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#ifndef PERMISSION_H
-#define PERMISSION_H
-
-#include "../config.h"
+#ifndef MPD_PERMISSION_H
+#define MPD_PERMISSION_H
 
 #define PERMISSION_NONE    0
 #define PERMISSION_READ    1
@@ -28,11 +26,11 @@
 #define PERMISSION_ADMIN   8
 
 
-int getPermissionFromPassword(char *password, int *permission);
+int getPermissionFromPassword(char *password, unsigned *permission);
 
 void finishPermissions(void);
 
-int getDefaultPermissions(void);
+unsigned getDefaultPermissions(void);
 
 void initPermissions(void);
 
