@@ -16,34 +16,12 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#ifndef PLAYER_DATA_H
-#define PLAYER_DATA_H
+#ifndef MPD_PLAYER_DATA_H
+#define MPD_PLAYER_DATA_H
 
-#include "../config.h"
-
-#include "audio.h"
-#include "player.h"
-#include "decode.h"
-#include "mpd_types.h"
-#include "outputBuffer.h"
-
-/* pick 1020 since its devisible for 8,16,24, and 32-bit audio */
-#define CHUNK_SIZE		1020
-
-extern int buffered_before_play;
-extern int buffered_chunks;
-
-typedef struct _PlayerData {
-	OutputBuffer buffer;
-	PlayerControl playerControl;
-	DecoderControl decoderControl;
-	mpd_uint8 *audioDeviceStates;
-} PlayerData;
+extern unsigned int buffered_chunks;
+extern unsigned int buffered_before_play;
 
 void initPlayerData(void);
 
-PlayerData *getPlayerData(void);
-
-void freePlayerData(void);
-
 #endif
