@@ -18,23 +18,17 @@
  */
 
 #include "sig_handlers.h"
-#include "player.h"
-#include "playerData.h"
 #include "playlist.h"
-#include "directory.h"
+#include "database.h"
+#include "update.h"
 #include "command.h"
 #include "signal_check.h"
 #include "log.h"
-#include "player.h"
-#include "decode.h"
 
-#include <signal.h>
-#include <sys/types.h>
-#include <sys/time.h>
-#include <sys/resource.h>
+#include <sys/signal.h>
 #include <sys/wait.h>
 #include <errno.h>
-#include <unistd.h>
+#include <glib.h>
 
 int handlePendingSignals(void)
 {
@@ -47,18 +41,17 @@ int handlePendingSignals(void)
 		DEBUG("got SIGHUP, rereading DB\n");
 		signal_clear(SIGHUP);
 		if (!isUpdatingDB()) {
-			readDirectoryDB();
+			db_load();
 			playlistVersionChange();
 		}
 		if (cycle_log_files() < 0)
 			return COMMAND_RETURN_KILL;
-		playerCycleLogFiles();
 	}
 
 	return 0;
 }
 
-static void chldSigHandler(int signal)
+static void chldSigHandler(G_GNUC_UNUSED int sig)
 {
 	int status;
 	int pid;
@@ -70,8 +63,6 @@ static void chldSigHandler(int signal)
 			else
 				break;
 		}
-		player_sigChldHandler(pid, status);
-		directory_sigChldHandler(pid, status);
 	}
 }
 
@@ -99,23 +90,6 @@ void finishSigHandlers(void)
 	signal_unhandle(SIGHUP);
 }
 
-void setSigHandlersForDecoder(void)
-{
-	struct sigaction sa;
-
-	finishSigHandlers();
-
-	sa.sa_flags = 0;
-	sigemptyset(&sa.sa_mask);
-	sa.sa_handler = SIG_IGN;
-	while (sigaction(SIGHUP, &sa, NULL) < 0 && errno == EINTR) ;
-	while (sigaction(SIGINT, &sa, NULL) < 0 && errno == EINTR) ;
-	sa.sa_flags = SA_SIGINFO;
-	sa.sa_sigaction = decodeSigHandler;
-	while (sigaction(SIGCHLD, &sa, NULL) < 0 && errno == EINTR) ;
-	while (sigaction(SIGTERM, &sa, NULL) < 0 && errno == EINTR) ;
-}
-
 void ignoreSignals(void)
 {
 	struct sigaction sa;
