@@ -16,10 +16,8 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#ifndef SIG_HANDLERS_H
-#define SIG_HANDLERS_H
-
-#include "../config.h"
+#ifndef MPD_SIG_HANDLERS_H
+#define MPD_SIG_HANDLERS_H
 
 int handlePendingSignals(void);
 
@@ -27,8 +25,6 @@ void initSigHandlers(void);
 
 void finishSigHandlers(void);
 
-void setSigHandlersForDecoder(void);
-
 void ignoreSignals(void);
 
 void blockSignals(void);
