@@ -19,17 +19,14 @@
 #include "../config.h"
 #include "state_file.h"
 #include "conf.h"
-#include "gcc.h"
 #include "log.h"
 #include "audio.h"
 #include "playlist.h"
 #include "utils.h"
 #include "volume.h"
 
-#include <errno.h>
-#include <stdlib.h>
+#include <glib.h>
 #include <string.h>
-#include <sys/types.h>
 #include <sys/stat.h>
 
 static struct _sf_cb {
@@ -55,14 +52,13 @@ static void get_state_file_path(void)
 
 void write_state_file(void)
 {
-	int i;
+	unsigned int i;
 	FILE *fp;
 
 	if (!sfpath)
 		return;
-	while (!(fp = fopen(sfpath, "w")) && errno == EINTR);
-
-	if (mpd_unlikely(!fp)) {
+	fp = fopen(sfpath, "w");
+	if (G_UNLIKELY(!fp)) {
 		ERROR("problems opening state file \"%s\" for writing: %s\n",
 		      sfpath, strerror(errno));
 		return;
@@ -77,7 +73,7 @@ void write_state_file(void)
 void read_state_file(void)
 {
 	struct stat st;
-	int i;
+	unsigned int i;
 	FILE *fp;
 
 	get_state_file_path();
@@ -91,7 +87,7 @@ void read_state_file(void)
 		FATAL("state file \"%s\" is not a regular file\n", sfpath);
 
 	while (!(fp = fopen(sfpath, "r")) && errno == EINTR);
-	if (mpd_unlikely(!fp)) {
+	if (G_UNLIKELY(!fp)) {
 		FATAL("problems opening state file \"%s\" for reading: %s\n",
 		      sfpath, strerror(errno));
 	}
@@ -103,9 +99,8 @@ void read_state_file(void)
 	while(fclose(fp) && errno == EINTR) /* nothing */;
 }
 
-void mpd_noreturn state_file_fatal(void)
+void G_GNUC_NORETURN state_file_fatal(void)
 {
 	FATAL("error parsing state file \"%s\"\n", sfpath);
-	exit(EXIT_FAILURE);
 }
 
