@@ -16,15 +16,13 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#ifndef STATE_FILE_H
-#define STATE_FILE_H
+#ifndef MPD_STATE_FILE_H
+#define MPD_STATE_FILE_H
 
-#include "gcc.h"
-
-#include <stdio.h>
+#include <glib.h>
 
 void write_state_file(void);
 void read_state_file(void);
-void mpd_noreturn state_file_fatal(void);
+void G_GNUC_NORETURN state_file_fatal(void);
 
 #endif /* STATE_FILE_H */
