@@ -16,12 +16,10 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#ifndef STATS_H
-#define STATS_H
+#ifndef MPD_STATS_H
+#define MPD_STATS_H
 
-#include "../config.h"
-
-#include <stdio.h>
+struct client;
 
 typedef struct _Stats {
 	unsigned long daemonStart;
@@ -35,6 +33,6 @@ extern Stats stats;
 
 void initStats(void);
 
-int printStats(int fd);
+int printStats(struct client *client);
 
 #endif
