@@ -16,25 +16,28 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#ifndef UTILS_H
-#define UTILS_H
-
-#include "../config.h"
-#include "gcc.h"
+#ifndef MPD_UTILS_H
+#define MPD_UTILS_H
 
+#include <glib.h>
 #include <unistd.h>
 #include <stdlib.h>
 #include <stdio.h>
 #include <errno.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <fcntl.h>
+#include <pthread.h>
 
 #define ARRAY_SIZE(x) (sizeof(x)/sizeof(x[0]))
 
-char *myFgets(char *buffer, int bufferSize, FILE * fp);
+#ifndef assert_static
+/* Compile time assertion developed by Ralf Holly */
+/* http://pera-software.com/articles/compile-time-assertions.pdf */
+#define assert_static(e) \
+	do { \
+		enum { assert_static__ = 1/(e) }; \
+	} while (0)
+#endif /* !assert_static */
 
-char *strDupToUpper(char *str);
+char *myFgets(char *buffer, int bufferSize, FILE * fp);
 
 void stripReturnChar(char *string);
 
@@ -42,10 +45,6 @@ void my_usleep(long usec);
 
 int ipv6Supported(void);
 
-char *appendToString(char *dest, const char *src);
-
-unsigned long readLEuint32(const unsigned char *p);
-
 /* trivial functions, keep them inlined */
 static inline void xclose(int fd)
 {
@@ -74,12 +73,39 @@ static inline ssize_t xwrite(int fd, const void *buf, size_t len)
 	}
 }
 
-mpd_malloc char *xstrdup(const char *s);
+G_GNUC_MALLOC char *xstrdup(const char *s);
 
-mpd_malloc void *xmalloc(size_t size);
+G_GNUC_MALLOC void *xmalloc(size_t size);
 
-mpd_malloc void *xrealloc(void *ptr, size_t size);
+G_GNUC_MALLOC void *xrealloc(void *ptr, size_t size);
 
-mpd_malloc void *xcalloc(size_t nmemb, size_t size);
+G_GNUC_MALLOC void *xcalloc(size_t nmemb, size_t size);
+
+/**
+ * free a const pointer - unfortunately free() expects a non-const
+ * pointer, for whatever reason
+ */
+static inline void xfree(const void *p)
+{
+	union {
+		const void *in;
+		void *out;
+	} deconst = { .in = p };
+	free(deconst.out);
+}
+
+char *parsePath(char *path);
+
+int set_nonblocking(int fd);
+
+void init_async_pipe(int file_des[2]);
+
+void xpthread_mutex_init(pthread_mutex_t *m, const pthread_mutexattr_t *a);
+
+void xpthread_cond_init(pthread_cond_t *c, pthread_condattr_t *a);
+
+void xpthread_mutex_destroy(pthread_mutex_t *mutex);
+
+void xpthread_cond_destroy(pthread_cond_t *cond);
 
 #endif
