@@ -16,10 +16,8 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#ifndef VOLUME_H
-#define VOLUME_H
-
-#include "../config.h"
+#ifndef MPD_VOLUME_H
+#define MPD_VOLUME_H
 
 #include <stdio.h>
 
@@ -35,7 +33,7 @@ void finishVolume(void);
 
 int getVolumeLevel(void);
 
-int changeVolumeLevel(int fd, int change, int rel);
+int changeVolumeLevel(int change, int rel);
 
 void read_sw_volume_state(FILE *fp);
 
