@@ -16,12 +16,21 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#ifndef ZEROCONF_H
-#define ZEROCONF_H
+#ifndef MPD_ZEROCONF_H
+#define MPD_ZEROCONF_H
 
 #include "../config.h"
 
+#ifdef HAVE_ZEROCONF
+
 void initZeroconf(void);
 void finishZeroconf(void);
 
+#else /* ! HAVE_ZEROCONF */
+
+static void initZeroconf(void) { }
+static void finishZeroconf(void) { }
+
+#endif /* ! HAVE_ZEROCONF */
+
 #endif
